@@ -149,7 +149,8 @@ QString SettingsPasswordRequester::requestManualAuth(bool *userRejected)
     dlg->setModal(true);
     dlg->setPrompt(i18n("Please enter password for user '%1' on IMAP server '%2'.", m_resource->settings()->userName(), m_resource->settings()->imapServer()));
     dlg->setPassword(m_resource->settings()->password());
-    dlg->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
+    dlg->setRevealPasswordMode(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")) ? KPassword::RevealMode::OnlyNew
+                                                                                                  : KPassword::RevealMode::Never);
     if (dlg->exec()) {
         if (userRejected) {
             *userRejected = false;
