@@ -18,6 +18,7 @@
 #include "setupserver.h"
 #include "folderarchivesettingpage.h"
 #include "imapresource.h"
+
 #include "serverinfodialog.h"
 #include "settings.h"
 #include <config-imap.h>
@@ -74,7 +75,7 @@ static QString authenticationModeString(MailTransport::Transport::EnumAuthentica
     case MailTransport::Transport::EnumAuthenticationType::ANONYMOUS:
         return i18nc("Authentication method", "Anonymous");
     case MailTransport::Transport::EnumAuthenticationType::XOAUTH2:
-        return i18nc("Authentication method", "Gmail");
+        return i18nc("Authentication method", "XOAuth");
     default:
         break;
     }
@@ -128,8 +129,10 @@ SetupServer::SetupServer(ImapResourceBase *parentResource, WId parent)
     mainLayout->addWidget(buttonBox);
 
     m_ui->setupUi(mainWidget);
-    m_ui->password->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
-    m_ui->customPassword->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
+    m_ui->password->setRevealPasswordMode(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")) ? KPassword::RevealMode::OnlyNew
+                                                                                                             : KPassword::RevealMode::Never);
+    m_ui->customPassword->setRevealPasswordMode(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")) ? KPassword::RevealMode::OnlyNew
+                                                                                                                   : KPassword::RevealMode::Never);
     KLineEditEventHandler::catchReturnKey(m_ui->accountName);
     KLineEditEventHandler::catchReturnKey(m_ui->imapServer);
     KLineEditEventHandler::catchReturnKey(m_ui->userName);
@@ -148,6 +151,7 @@ SetupServer::SetupServer(ImapResourceBase *parentResource, WId parent)
 
     m_ui->testInfo->hide();
     m_ui->testProgress->hide();
+    m_ui->testProgress->setFormat(i18nc("Percent value; %p is the value, % is the percent sign", "%p%"));
     m_ui->accountName->setFocus();
     m_ui->checkInterval->setSuffix(ki18np(" minute", " minutes"));
     m_ui->checkInterval->setMinimum(Akonadi::ResourceSettings::self()->minimumCheckInterval());
@@ -272,11 +276,11 @@ void SetupServer::applySettings()
 
     const MailTransport::Transport::EnumAuthenticationType authtype = getCurrentAuthMode(m_ui->authenticationCombo);
     if (!m_ui->userName->text().contains(QLatin1Char('@')) && authtype == MailTransport::Transport::EnumAuthenticationType::XOAUTH2
-        && m_ui->imapServer->text().contains(QLatin1String("gmail.com"))) {
+        && m_ui->imapServer->text().contains(QLatin1StringView("gmail.com"))) {
         // Normalize gmail username so that it matches the JSON account info returned by GMail authentication.
         // If we don't do this, we will look up cached auth without @gmail.com and save it with @gmail.com => very frequent auth dialog popping up.
         qCDebug(IMAPRESOURCE_LOG) << "Fixing up username" << m_ui->userName->text() << "by adding @gmail.com";
-        m_ui->userName->setText(m_ui->userName->text() + QLatin1String("@gmail.com"));
+        m_ui->userName->setText(m_ui->userName->text() + QLatin1StringView("@gmail.com"));
     }
 
     m_parentResource->setName(m_ui->accountName->text());
@@ -379,9 +383,9 @@ void SetupServer::readSettings()
 
     const QString safety = m_parentResource->settings()->safety();
     int i = 0;
-    if (safety == QLatin1String("SSL")) {
+    if (safety == QLatin1StringView("SSL")) {
         i = KIMAP::LoginJob::SSLorTLS;
-    } else if (safety == QLatin1String("STARTTLS")) {
+    } else if (safety == QLatin1StringView("STARTTLS")) {
         i = KIMAP::LoginJob::STARTTLS;
     } else {
         i = KIMAP::LoginJob::Unencrypted;
@@ -473,11 +477,11 @@ void SetupServer::readSettings()
     }
 
     const QString sieverCustomAuth(m_parentResource->settings()->sieveCustomAuthentification());
-    if (sieverCustomAuth == QLatin1String("ImapUserPassword")) {
+    if (sieverCustomAuth == QLatin1StringView("ImapUserPassword")) {
         m_ui->imapUserPassword->setChecked(true);
-    } else if (sieverCustomAuth == QLatin1String("NoAuthentification")) {
+    } else if (sieverCustomAuth == QLatin1StringView("NoAuthentification")) {
         m_ui->noAuthentification->setChecked(true);
-    } else if (sieverCustomAuth == QLatin1String("CustomUserPassword")) {
+    } else if (sieverCustomAuth == QLatin1StringView("CustomUserPassword")) {
         m_ui->customUserPassword->setChecked(true);
     }
 
